#!/bin/ksh

ECHO="/bin/echo"

WCS_HOME=$1
APAR_NUM="IY56108"
DELTA_JAR="Delta.jar"

$ECHO "   "
$ECHO "WebSphere Commerce" $APAR_NUM "install for AIX"
$ECHO "Please shut down the Application Server and any Webservers that might be running"
$ECHO "   "

# print usage.
print_usage() {
   $ECHO "usage: `basename $0` <wc_home> <was_home> <wc_application_home > <wc_dbtype>"
   $ECHO "Example: ./install_was.sh /usr/WebSphere/CommerceServer /usr/WebSphere/AppServer WC_Enterprise_App_[instance].ear db2"
   $ECHO "Example: ./install_was.sh /usr/WebSphere/CommerceServer /usr/WebSphere/AppServer WC_Enterprise_App_[instance].ear oracle"
}

check_dbtype() {
if [[ $WC_DBTYPE != "db2" && $WC_DBTYPE != "oracle" ]]
then
        $ECHO "Incorrect Database type - Exiting"
        exit 0
fi
}

# checks if required directories exist.
check_paths() {
local val=1

   if [ -d $WAS_HOME ] && val=2 && \
      [ -d $WAS_HOME/installedApps/$WC_APPLICATION_HOME ] && val=3 && \
      [ -d $WC_HOME ]
   then
        $ECHO "---- Components path check passed -----"
        return $TRUE
   else
        $ECHO "---- Please correct following error: ----"

        case $val in
           1) $ECHO "Invalid WAS_HOME directory."
              ;;
           2) $ECHO "Invalid WC_APPLICATION_HOME directory."
              ;;
           3) $ECHO "Invalid WC_HOME directory."
              ;;
        esac
   fi
   return $FALSE
}



# checks if required files exist.
check_files() {
local val=1

   if [ -f $WAS_HOME/java/jre/bin/java ] && val=2 && \
      [ -f ./$WCS_APAR_JAR ] && val=3 && \
      [ -f ./$DELTA_JAR ] && val=4 && \
      [ -f $WAS_HOME/properties/com/ibm/websphere/product.xml ] && val=5 && \
      [ -f $WC_HOME/xml/product.xml ]
   then
#   	$ECHO "---- Files check passed ----"
	return $TRUE
   else
   	$ECHO "---- Please correct following error: ----"

	case $val in
	   1) $ECHO "The following file does not exist: $WAS_HOME/java/jre/bin/java"
	      ;;
	   2) $ECHO "The following file does not exist: $WCS_APAR_JAR"
              ;;
	   3) $ECHO "The following file does not exist: $DELTA_JAR"
	      ;;
           4) $ECHO "The following file does not exist: $WAS_HOME/properties/com/ibm/websphere/product.xml"
              ;;
           5) $ECHO "The following file does not exist: $WC_HOME/xml/product.xml"
              ;;
	esac
   fi

   return $FALSE;
}


# make service directories
make_service_dir() {

   if [ -d $WCS_SERVICE_DIR ]; then
   	if [ -d $WCS_EFIX_DIR ]; then
	   if [ -d $WCS_APAR_DIR ]; then
	      return
	   else
	      mkdir $WCS_EFIX_DIR
	   fi
	else
	   mkdir $WCS_EFIX_DIR
	   mkdir $WCS_APAR_DIR
	fi
   else
      mkdir $WCS_SERVICE_DIR
      mkdir $WCS_EFIX_DIR
      mkdir $WCS_APAR_DIR
   fi
}

# beginning of script.
TRUE=0
FALSE=1

#ensure correct number of arguments provided.
if [ $# -ne 4 ]; then
   print_usage
   exit 0
else
   WC_HOME=$1
   WAS_HOME=$2
   WC_APPLICATION_HOME=$3
   WC_DBTYPE=$4
   WCS_SERVICE_DIR="$WCS_HOME"/service
   WCS_EFIX_DIR="$WCS_HOME"/service/fix
   WCS_APAR_DIR="$WCS_HOME"/service/fix/"$APAR_NUM"
   WCS_APAR_JAR="$APAR_NUM"_was_AIX.jar
   WCS_BACKUP_JAR="$WC_APPLICATION_HOME"_backup.jar
fi


# check if necessary components install path exist.
if check_paths; then
   $ECHO "main - check path PASSED."
else
   $ECHO "main - check path FAILED."
   exit 0
fi

# check if necessary files exist.
if check_files; then
   $ECHO "main - check files PASSED."
else
   $ECHO "main - check files FAILED."
   exit 0
fi


# make service directories
make_service_dir
$ECHO "main - service directories exist/created."

# Install WebSphere Commerce eFix, AIX
$ECHO "main - Installing eFix" $APAR_NUM "for AIX"

$ECHO "main - Checking Database"
check_dbtype

$WAS_HOME/java/jre/bin/java -Ddbtype=$WC_DBTYPE -jar $WCS_APAR_JAR -TargetDir $WAS_HOME/installedApps/$WC_APPLICATION_HOME -backupJar $WCS_APAR_DIR/$WCS_BACKUP_JAR -log $WCS_APAR_DIR/$WC_APPLICATION_HOME.log

status=$?

if [ $status = 8 ]; then
   $ECHO "exiting install due to user intervention"
   exit 0
fi

$ECHO "main - installing fix complete."
$ECHO "main - Installing eFix" $APAR_NUM "complete"
$ECHO "Please review the readme for any additional instructions."

exit 0 
